# AWS Bootstrap Kit main package

Expose a set of stacks and constructs to help you get started properly on AWS.

## Usage

1. install

   ```
   npm install aws-bootstrap-kit
   ```
2. Check the [Examples](https://github.com/aws-samples/aws-bootstrap-kit-examples) and [API Doc](./API.md) for more details

## Contributing

Check [CONTRIBUTING.md](/source/aws-bootstrap-kit/CONTRIBUTING.md)
